# Changelog

## 0.6.3 2023 Nov 27

- reimplement toggling of courselevels with md_toggle_multi
- use nested css

## 0.6.2 2023 Oct 1

- add a settings to enable/disable the menubar buttons

## 0.6.0 2023 Sep 30

- keyboard shortcuts all protected by `Ctrl-\` because e.g. `Ctrl-X` is already
  the usual Cut command
- add support for admonitions
- add support to clean metadata

## 0.4.2 2023 Jul 2

- initial release
